==> xcfa_3.4.9.orig.tar.gz: xcfa-3.4.9/src/process.h <==
 /*
 * file      : process.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003,2004,2005,2006,2007,2008,2009 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifndef __process_h__
#define ___process_h__ 1


#define XCFA_FILE_LOAD		"/tmp/xcfa_file_load.txt"
#define XCFA_PROCESS		"/tmp/xcfa_pid.txt"


typedef struct {
	guint          handler_timeout;
	gboolean       bool_read_access;
	gboolean       bool_action_is_ready;
} VAR_PROCESS;

extern VAR_PROCESS var_process;


void		process_goto_timeout (void);
gboolean	process_bool_action_is_ready (void);

#endif

==> xcfa_3.7.3.orig.tar.gz: xcfa-3.7.3/src/process.h <==
 /*
 * file      : process.h
 * project   : xcfa
 * with      : Gtk-2
 *
 * copyright : (C) 2003 - 2010 by Claude Bulin
 *
 * xcfa - GTK+ implementation of the GNU shell command
 * GNU General Public License
 *
 * This program is free software; you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * OLD ADRESS:
 * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 * NEW ADRESS:
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA 02110-1301, USA
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 * 
 */


#ifndef __process_h__
#define ___process_h__ 1


#define XCFA_FILE_LOAD		"/tmp/xcfa_file_load.txt"
#define XCFA_PROCESS		"/tmp/xcfa_process.txt"
#define XCFA_PID		"/tmp/xcfa_pid.txt"


typedef struct {
	guint          handler_timeout;
	gboolean       bool_read_access;
	gboolean       bool_action_is_ready;
} VAR_PROCESS;

extern VAR_PROCESS var_process;


void		process_goto_timeout (void);
gboolean	process_bool_action_is_ready (void);

#endif
